@@ -45,10 +45,11 @@
 
 #include "test.h"
 
-static char tmpdir[] = "/tmp/nbdkitXXXXXX";
-static char sockpath[] = "/tmp/nbdkitXXXXXX/sock";
+/* test_start_nbdkit below makes assumptions about the format of these strings */
+static char tmpdir[] =            "/tmp/nbdkitXXXXXX";
+static char sockpath[] =          "/tmp/nbdkitXXXXXX/sock";
 static char unixsockpath[] = "unix:/tmp/nbdkitXXXXXX/sock";
-static char pidpath[] = "/tmp/nbdkitXXXXXX/pid";
+static char pidpath[] =           "/tmp/nbdkitXXXXXX/pid";
 
 pid_t pid = 0;
 const char *server[2] = { unixsockpath, NULL };
@@ -91,8 +92,9 @@ test_start_nbdkit (const char *plugin, ...)
     argv[3] = "-P";
     argv[4] = pidpath;
     argv[5] = "-f";
-    argv[6] = plugin;
-    i = 7;
+    argv[6] = "-v";
+    argv[7] = plugin;
+    i = 8;
 
     va_start (args, plugin);
     while ((p = va_arg (args, const char *)) != NULL) {
